# The Awesome Panel Project

We want to

- show how awesome [Panel](https://awesome-panel.org) is and help push the [Panel](https://awesome-panel.org) framework and community forward.

We provide

- The [awesome-panel.org](https://awesome-panel.org) web site with *awesome lists*, example apps and more.
- A [**Youtube Playlist**](https://www.youtube.com/playlist?list=PLrrcIlm1vLr69f4CsTlrO0wSNBw6VbsJA).
- A large gallery of awesome Panel examples.
- A large collection of awesome [Panel extensions](https://github.com/orgs/awesome-panel/repositories).

This project is developed by Marc Skov Madsen. Feel free to reach out if you want to join the project as a developer.

You can find my contact details at [datamodelsanalytics.com](https://datamodelsanalytics.com).

<div align="center" style="margin-right:10%;margin-left:10%">
<a href="https://datamodelsanalytics.com">
    <img
        alt="ECharts"
        src="https://cdn.jsdelivr.net/gh/awesome-panel/awesome-panel-assets@5a86c80316da7a86ee0e4bfee0142e607a27e1c4/images/datamodelsanalytics.png"
        style="height:300px;"
    ></a>
</div>
